Actions, Resources, and Condition Keys for AWS Direct Connect - AWS Identity and Access Management
Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to AWS Direct Connect.
Keywords: IAM,AWS Identity and Access Management,IAM user,user,IAM group,group,IAM role,role,permission policy,trust policy,policy,access key,password

AWS Identity and Access Management
User Guide

# Actions, Resources, and Condition Keys for AWS Direct Connect

AWS Direct Connect (service prefix: `directconnect`) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service.

- View a list of the API operations available for this service.

- Learn how to secure this service and its resources by using IAM permission policies.

Topics

- Actions Defined by AWS Direct Connect
- Resources Defined by AWS Direct Connect
- Condition Keys for AWS Direct Connect

## Actions Defined by AWS Direct Connect

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource column indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. Required resources are indicated in the table with an asterisk (*). If you specify a resource-level permission ARN in a statement using this action, then it must be of this type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one but not the other.

For details about the columns in the following table, see The Actions Table.

Actions | Description | Access Level | Resource Types (*required) | Condition Keys | Dependent Actions
--- | --- | --- | --- | --- | ---
AcceptDirectConnectGatewayAssociationProposal | Accepts a proposal request to attach a virtual private gateway to a Direct Connect gateway. | Write | dx-gateway* |  |
AllocateConnectionOnInterconnect | Creates a hosted connection on an interconnect. | Write | dxcon* |  |
AllocateHostedConnection | Creates a new hosted connection between a AWS Direct Connect partner's network and a specific AWS Direct Connect location. | Write | dxcon |  |
dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
AllocatePrivateVirtualInterface | Provisions a private virtual interface to be owned by a different customer. | Write | dxcon |  |
dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
AllocatePublicVirtualInterface | Provisions a public virtual interface to be owned by a different customer. | Write | dxcon |  |
dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
AllocateTransitVirtualInterface | Provisions a transit virtual interface to be owned by a different customer. | Write | dxcon |  |
dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
AssociateConnectionWithLag | Associates a connection with a LAG. | Write | dxcon* |  |
dxlag* |  |
AssociateHostedConnection | Associates a hosted connection and its virtual interfaces with a link aggregation group (LAG) or interconnect. | Write | dxcon* |  |
dxcon |  |
dxlag |  |
AssociateVirtualInterface | Associates a virtual interface with a specified link aggregation group (LAG) or connection. | Write | dxvif* |  |
dxcon |  |
dxlag |  |
ConfirmConnection | Confirm the creation of a hosted connection on an interconnect. | Write | dxcon* |  |
ConfirmPrivateVirtualInterface | Accept ownership of a private virtual interface created by another customer. | Write | dxvif* |  |
ConfirmPublicVirtualInterface | Accept ownership of a public virtual interface created by another customer | Write | dxvif* |  |
ConfirmTransitVirtualInterface | Accept ownership of a transit virtual interface created by another customer | Write | dxvif* |  |
CreateBGPPeer | Creates a BGP peer on the specified virtual interface. | Write | dxvif* |  |
CreateConnection | Creates a new connection between the customer network and a specific AWS Direct Connect location. | Write | dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDirectConnectGateway | Creates a Direct Connect gateway, which is an intermediate object that enables you to connect a set of virtual interfaces and virtual private gateways. | Write |  |  |
CreateDirectConnectGatewayAssociation | Creates an association between a Direct Connect gateway and a virtual private gateway. | Write | dx-gateway* |  |
CreateDirectConnectGatewayAssociationProposal | Creates a proposal to associate the specified virtual private gateway with the specified Direct Connect gateway. | Write | dx-gateway* |  |
CreateInterconnect | Creates a new interconnect between a AWS Direct Connect partner's network and a specific AWS Direct Connect location. | Write | dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateLag | Creates a link aggregation group (LAG) with the specified number of bundled physical connections between the customer network and a specific AWS Direct Connect location. | Write | dxcon |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePrivateVirtualInterface | Creates a new private virtual interface. | Write | dxcon |  |
dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreatePublicVirtualInterface | Creates a new public virtual interface. | Write | dxcon |  |
dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateTransitVirtualInterface | Creates a new transit virtual interface. | Write | dxcon |  |
dxlag |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
DeleteBGPPeer | Deletes the specified BGP peer on the specified virtual interface with the specified customer address and ASN. | Write | dxvif* |  |
DeleteConnection | Deletes the connection. | Write | dxcon* |  |
DeleteDirectConnectGateway | Deletes the specified Direct Connect gateway. | Write | dx-gateway* |  |
DeleteDirectConnectGatewayAssociation | Deletes the association between the specified Direct Connect gateway and virtual private gateway. | Write | dx-gateway* |  |
DeleteDirectConnectGatewayAssociationProposal | Deletes the association proposal request between the specified Direct Connect gateway and virtual private gateway. | Write |  |  |
DeleteInterconnect | Deletes the specified interconnect. | Write | dxcon* |  |
DeleteLag | Deletes the specified link aggregation group (LAG). | Write | dxlag* |  |
DeleteVirtualInterface | Deletes a virtual interface. | Write | dxvif* |  |
DescribeConnectionLoa | Returns the LOA-CFA for a Connection. | Read | dxcon* |  |
DescribeConnections | Displays all connections in this region. | Read | dxcon |  |
DescribeConnectionsOnInterconnect | Return a list of connections that have been provisioned on the given interconnect. | Read | dxcon* |  |
DescribeDirectConnectGatewayAssociationProposals | Describes one or more association proposals for connection between a virtual private gateway and a Direct Connect gateway. | Read | dx-gateway |  |
DescribeDirectConnectGatewayAssociations | Lists the associations between your Direct Connect gateways and virtual private gateways. | Read | dx-gateway |  |
DescribeDirectConnectGatewayAttachments | Lists the attachments between your Direct Connect gateways and virtual interfaces. | Read | dx-gateway |  |
DescribeDirectConnectGateways | Lists all your Direct Connect gateways or only the specified Direct Connect gateway. | Read | dx-gateway |  |
DescribeHostedConnections | Lists the hosted connections that have been provisioned on the specified interconnect or link aggregation group (LAG). | Read | dxcon |  |
dxlag |  |
DescribeInterconnectLoa | Returns the LOA-CFA for an Interconnect. | Read | dxcon* |  |
DescribeInterconnects | Returns a list of interconnects owned by the AWS account. | Read | dxcon |  |
DescribeLags | Describes all your link aggregation groups (LAG) or the specified LAG. | Read | dxlag |  |
DescribeLoa | Gets the LOA-CFA for a connection, interconnect, or link aggregation group (LAG). | Read | dxcon |  |
dxlag |  |
DescribeLocations | Returns the list of AWS Direct Connect locations in the current AWS region. | List |  |  |
DescribeTags | Describes the tags associated with the specified AWS Direct Connect resources. | Read | dxcon |  |
dxlag |  |
dxvif |  |
DescribeVirtualGateways | Returns a list of virtual private gateways owned by the AWS account. | Read |  |  |
DescribeVirtualInterfaces | Displays all virtual interfaces for an AWS account. | Read | dxcon |  |
dxlag |  |
dxvif |  |
DisassociateConnectionFromLag | Disassociates a connection from a link aggregation group (LAG). | Write | dxcon* |  |
dxlag* |  |
TagResource | Adds the specified tags to the specified AWS Direct Connect resource. Each resource can have a maximum of 50 tags. | Tagging | dxcon |  |
dxlag |  |
dxvif |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Removes one or more tags from the specified AWS Direct Connect resource. | Tagging | dxcon |  |
dxlag |  |
dxvif |  |
| aws:TagKeys |
UpdateDirectConnectGatewayAssociation | Updates the specified attributes of the Direct Connect gateway association. | Write |  |  |
UpdateLag | Updates the attributes of the specified link aggregation group (LAG). | Write | dxlag* |  |
UpdateVirtualInterfaceAttributes | Updates the specified attributes of the specified virtual private interface. | Write | dxvif* |  |

## Resources Defined by AWS Direct Connect

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the table. For details about the columns in the following table, see The Resource Types Table.

Resource Types | ARN | Condition Keys
--- | --- | ---
dxcon | `arn:${Partition}:directconnect:${Region}:${Account}:dxcon/${ConnectionId}` | aws:ResourceTag/${TagKey}
dxlag | `arn:${Partition}:directconnect:${Region}:${Account}:dxlag/${LagId}` | aws:ResourceTag/${TagKey}
dxvif | `arn:${Partition}:directconnect:${Region}:${Account}:dxvif/${VirtualInterfaceId}` | aws:ResourceTag/${TagKey}
dx-gateway | `arn:${Partition}:directconnect::${Account}:dx-gateway/${DirectConnectGatewayId}` |

## Condition Keys for AWS Direct Connect

AWS Direct Connect defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see The Condition Keys Table.

To view the global condition keys that are available to all services, see Available Global Condition Keys in the IAM Policy Reference.

Condition Keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters actions based on the presence of tag key-value pairs in the request | String
aws:ResourceTag/${TagKey} | Filters actions based on tag key-value pairs attached to the resource | String
aws:TagKeys | Filters actions based on the presence of tag keys in the request | String

On this page:

- Actions Defined by AWS Direct Connect
- Resources Defined by AWS Direct Connect
- Condition Keys for AWS Direct Connect

We use cookies to provide and improve our services. By using our site, you consent to cookies. Learn more